ps_ouss_gradient_wrt_power_e <-
function(freq, power_o, lambda, power_e, time_step, series_size){
	return(rep(1,length(freq)));
}
